import { TrackerPluginInterface, TrackerConsole, TrackerPluginConfig, ContextsConfig } from '@objectiv/tracker-core';

/**
 * The PathContextFromURL Plugin gathers the current URL using the Location API.
 * It implements the `beforeTransport` lifecycle method. This ensures the URL is retrieved before each Event is sent.
 */
declare class PathContextFromURLPlugin implements TrackerPluginInterface {
    readonly console?: TrackerConsole;
    readonly pluginName = "PathContextFromURLPlugin";
    /**
     * The constructor is merely responsible for processing the given TrackerPluginConfiguration `console` parameter.
     */
    constructor(config?: TrackerPluginConfig);
    /**
     * Generate a fresh PathContext before each TrackerEvent is handed over to the TrackerTransport.
     */
    beforeTransport(contexts: Required<ContextsConfig>): void;
    /**
     * Make this plugin usable only on web, eg: Document and Location APIs are both available
     */
    isUsable(): boolean;
}

export { PathContextFromURLPlugin };
